/* =======================================
	Temperature Distribution
	Thermal Diffusion Equation
	--------------------------
	Author: _________
	Date: 20__.__.__
	--------------------------
	Geometry File:	___.geo
	Mesh File:	___.msh
   ======================================= */

/* ==== Group Definition ==== */
Group {
	Box_Vol = Region[1001] ;
	Box_Bottom_Surface = Region[1002] ;
	Box_Top_Surface = Region[1003] ;
	Box_Side_Surface = Region[1004] ;
	
	All_Volume = Region[Box_Vol] ;
	All_Surface = Region[{ Box_Bottom_Surface, Box_Top_Surface, Box_Side_Surface }] ;
	

}
/* ==== End of Group Definition ==== */

/* ==== Function Definition ==== */
Function {
	D[Box_Vol] = 1.1e-4;	// Coefficient of Thermal Diffusion
	D[All_Surface] = 1.1e-4;
	CV[Box_Vol] = 3.7e6;	// Volumetric Heat Capacity
	TC[] = D[] * CV[] ;	// Thermal Conductivity
	
	mm = 1e-3 ;
	L = 1.0 * mm ;
	W = 2.0 * mm ;
	H = 5.0 * mm ;
	
	VOL = L * W * H ;	// Volume
	AREA = L * W ;
	JHS = 1.0 ;		// Joule Heat of Source
	js[] = JHS/VOL ;
	fluxin[] = JHS/AREA ;
	
	sigma = 5.67e-8;	// Stephan-Boltzmann Constant
	
	TRAD[All_Surface] = sigma ;
	
	Troom = 300 ;
	Tref = 300 ;
	Tinit = 500 ;
	
	T0 = 300 ;
	T1 = 400 ;
	
	// t0,t1,dt,iter_theta
	t0 = 0 ;
	t1 = 100 ;
	dt = 10 ;
	iter_theta = 1.0 ; 
}
/* ==== End of Function Definition ==== */

/* ==== Constraint Definition ==== */
Constraint {
	{ Name T_INIT ;
		Case {
			{ Region All_Volume ; Type Init ; Value Tinit ; }
			{ Region All_Surface ; Type Init ; Value Tinit ; }
		}
	}
	
	{ Name T_STATIC ;
		Case { 
			{ Region Box_Bottom_Surface ; Type Assign ; Value T0 ; }
			{ Region Box_Top_Surface ; Type Assign ; Value T1 ; }
		}
	}
}
/* ==== End of Constraint Definition ==== */

/* ==== Jacobian ==== */
// General Example

Jacobian {
	{ Name Jac ;
		Case {
			{ Region All_Volume ; Jacobian Vol ; }
			{ Region All_Surface ; Jacobian Sur ; }
		}
	}
}
/* ==== End of Jacobian ==== */

/* ==== Integration ==== */
// Example

Integration {
	{ Name I1;
		Case { 
			{ Type Gauss ;
				Case {
					{GeoElement Triangle ; NumberOfPoints 3 ;}
					{GeoElement Quadrangle ; NumberOfPoints 4;}
					{GeoElement Tetrahedron ; NumberOfPoints 4 ;}
					{GeoElement Hexahedron  ; NumberOfPoints 8 ;}
					{GeoElement Prism ; NumberOfPoints 9 ;}
				}
			}
		}
	}
}
/* ==== End of Integration ==== */

/* ==== Function Space ==== */
FunctionSpace {
	{ Name DGrad_T ; Type Form0 ;
		BasisFunction {
			{ Name sn ; NameOfCoef Tn ; Function BF_Node ;
			  Support All_Volume ; Entity NodesOf[ All ] ; }
		}
		Constraint {
			{ NameOfCoef Tn ; EntityType NodesOf ; NameOfConstraint T_INIT ;}
		}
	}
	
	{ Name Sta_DGrad_T ; Type Form0 ;
		BasisFunction {
			{ Name sn ; NameOfCoef Tn ; Function BF_Node ;
			  Support All_Volume ; Entity NodesOf[ All ] ; }
		}
		Constraint {
			{ NameOfCoef Tn ; EntityType NodesOf ; NameOfConstraint T_STATIC ;}
		}
	}
}
/* ==== End of Function Space */

/* ==== Formulation ==== */
Formulation {
	{ Name Sta_T ; Type FemEquation ;
		Quantity {
			{ Name T ; Type Local ; NameOfSpace Sta_DGrad_T ; }
		}
		Equation {
			Galerkin { [ Dof{T}, {T} ] ;
				In All_Volume ; Jacobian Jac ; Integration I1 ;
			}
			
			Galerkin { [ D[] * Dof{d T}, {d T} ] ;
				In All_Volume ; Jacobian Jac ; Integration I1 ;
			}
			/*
			Galerkin {  [ -fluxin[], {T} ] ;
				In Box_Top_Surface ; Jacobian Jac ; Integration I1 ;
			}*/
		}
	
	}


	{ Name Dyn_T ; Type FemEquation ;
		Quantity {
			{ Name T ; Type Local ; NameOfSpace DGrad_T ; }
		}
		Equation {
			Galerkin { Dt[ CV[] * Dof{T}, {T} ] ;
				In All_Volume ; Jacobian Jac ; Integration I1 ;
			}
			
			Galerkin { [ TC[] * Dof{Grad T}, {Grad T} ] ;
				In All_Volume ; Jacobian Jac ; Integration I1 ;
			}
			/*
			Galerkin { [ -fluxin[], {T} ] ;
				In Box_Top_Surface ; Jacobian Jac ; Integration I1 ;
			}*/
			/*
			Galerkin { [ TRAD[] * ({T}^3 * Dof{T} - Tref^4), {T} ] ;
				In Box_Side_Surface ; Jacobian Jac ; Integration I1 ;
			}*/			
		}
	}

}

/* ==== End of Formulation ==== */

/* ==== Resolution ==== */
Resolution {
	{ Name Sta_T ;
		System {
			{ Name T ; NameOfFormulation Sta_T ; }
		}
		Operation {
			Generate[T] ;
			Solve[T] ;
			SaveSolution[T] ;
		}
	
	}

	{ Name Dyn_T ;
	  	System {
			{ Name T ; NameOfFormulation Dyn_T ; }
		}
	 	Operation {
	 		InitSolution[T] ;
	 		SaveSolution[T] ; 
	 		TimeLoopTheta[t0, t1, dt, iter_theta]{
				Generate[T];
				Solve[T];
				SaveSolution[T];
			}
	 	}
	
	}
}
/* ==== End of Resolution ==== */

/* ==== Post Processing ==== */
PostProcessing {
	{ Name Dyn_T ; NameOfFormulation Dyn_T ;
		Quantity {
			{ Name T ; Value {Local {[{T}] ; In All_Volume ; Jacobian Jac ; } } }
		}
	}
	{ Name Sta_T ; NameOfFormulation Sta_T ;
		Quantity {
			{ Name T ; Value {Local {[{T}] ; In All_Volume ; Jacobian Jac ; } } }
			{ Name T ; Value {Local {[{T}] ; In All_Surface ; Jacobian Jac ; } } }
		}
	}

}
/* ==== End of Post Processing ==== */

/* ==== Post Operation ==== */
// eps = ...

PostOperation {
	{ Name Dyn_T ; NameOfPostProcessing Dyn_T ;
		Operation {
			Print[ T, OnElementsOf All_Volume, File "T_Volume.pos" ] ;
			Print[ T, OnElementsOf Box_Side_Surface, File "T_Surface.pos" ] ;
		}
	}
	{ Name Dyn_T_CrossSurf ; NameOfPostProcessing Dyn_T ;
		Operation {
			Print [ T, OnSection {{0,0,0}{1 * mm,0,0}{0,1 * mm,0}}, File "T_Cross_Surface_1.pos"] ;
			Print [ T, OnSection {{0,0,0}{1 * mm,0,0}{0,0,1 * mm}}, File "T_Cross_Surface_2.pos"] ;
			Print [ T, OnSection {{0,0,0}{0,0,1 * mm}{0,1 * mm,0}}, File "T_Cross_Surface_3.pos"] ;
		}
	}
	{ Name Sta_T ; NameOfPostProcessing Sta_T ;
		Operation {
			Print[ T, OnElementsOf All_Volume, File "Sta_T_Volume.pos" ] ;
			Print[ T, OnElementsOf Box_Side_Surface, File "Sta_T_Side_Surface.pos" ] ;
			Print[ T, OnElementsOf All_Surface, File "Sta_T_All_Surface.pos" ] ;
			Print [ T, OnSection {{0,0,0}{1 * mm,0,0}{0,1 * mm,0}}, File "Sta_T_Cross_Surface_1.pos"] ;
			Print [ T, OnSection {{0,0,0}{1 * mm,0,0}{0,0,1 * mm}}, File "Sta_T_Cross_Surface_2.pos"] ;
			Print [ T, OnSection {{0,0,0}{0,0,1 * mm}{0,1 * mm,0}}, File "Sta_T_Cross_Surface_3.pos"] ;
		}
	}
}

/* ==== End of Post Operation ==== */


